ObjDateTimeExt extension

on

Properties

day → int

Available on Obj<DateTime>, provided by the ObjDateTimeExt extension

The day of the month [1..31].
no setter
hour → int

Available on Obj<DateTime>, provided by the ObjDateTimeExt extension

The hour of the day, expressed as in a 24-hour clock [0..23].
no setter
microsecond → int

Available on Obj<DateTime>, provided by the ObjDateTimeExt extension

The microsecond [0...999].
no setter
microsecondsSinceEpoch → int

Available on Obj<DateTime>, provided by the ObjDateTimeExt extension

The number of microseconds since the "Unix epoch" 1970-01-01T00:00:00Z (UTC).
no setter
millisecond → int

Available on Obj<DateTime>, provided by the ObjDateTimeExt extension

The millisecond [0...999].
no setter
millisecondsSinceEpoch → int

Available on Obj<DateTime>, provided by the ObjDateTimeExt extension

The number of milliseconds since the "Unix epoch" 1970-01-01T00:00:00Z (UTC).
no setter
minute → int

Available on Obj<DateTime>, provided by the ObjDateTimeExt extension

The minute [0...59].
no setter
month → int

Available on Obj<DateTime>, provided by the ObjDateTimeExt extension

The month [1..12].
no setter
second → int

Available on Obj<DateTime>, provided by the ObjDateTimeExt extension

The second [0...59].
no setter
timeZoneName → String

Available on Obj<DateTime>, provided by the ObjDateTimeExt extension

The time zone name.
no setter
timeZoneOffset → Duration

Available on Obj<DateTime>, provided by the ObjDateTimeExt extension

The time zone offset, which is the difference between local time and UTC.
no setter
weekday → int

Available on Obj<DateTime>, provided by the ObjDateTimeExt extension

The day of the week monday..sunday.
no setter
year → int

Available on Obj<DateTime>, provided by the ObjDateTimeExt extension

The year.
no setter

Methods

add(Duration duration) → DateTime

Available on Obj<DateTime>, provided by the ObjDateTimeExt extension

Returns a new DateTime instance with duration added to this.
compareTo(DateTime other) → int

Available on Obj<DateTime>, provided by the ObjDateTimeExt extension

Compares this DateTime object to other, returning zero if the values are equal.
difference(DateTime other) → Duration

Available on Obj<DateTime>, provided by the ObjDateTimeExt extension

Returns a Duration with the difference when subtracting other from this.
isAfter(DateTime other) → bool

Available on Obj<DateTime>, provided by the ObjDateTimeExt extension

Returns true if this occurs after other.
isAtSameMomentAs(DateTime other) → bool

Available on Obj<DateTime>, provided by the ObjDateTimeExt extension

Returns true if this occurs at the same moment as other.
isBefore(DateTime other) → bool

Available on Obj<DateTime>, provided by the ObjDateTimeExt extension

Returns true if this occurs before other.
subtract(Duration duration) → DateTime

Available on Obj<DateTime>, provided by the ObjDateTimeExt extension

Returns a new DateTime instance with duration subtracted from this.
toIso8601String() → String

Available on Obj<DateTime>, provided by the ObjDateTimeExt extension

Returns an ISO-8601 full-precision extended format representation.
toLocal() → DateTime

Available on Obj<DateTime>, provided by the ObjDateTimeExt extension

Returns this DateTime value in the local time zone.
toUtc() → DateTime

Available on Obj<DateTime>, provided by the ObjDateTimeExt extension

Returns this DateTime value in the UTC time zone.